/* 
 * ImageShowing.h created by probert on 2001-11-17 14:50:02 +0000
 *
 * Project ImageViewer
 *
 * Created with ProjectCenter - http://www.projectcenter.ch
 *
 * $Id: ImageShowing.h,v 1.3 2003/05/16 19:29:51 philippe Exp $
 */

#ifndef _IMAGESHOWING_H_
#define _IMAGESHOWING_H_

@protocol ImageShowing <NSObject>

- (NSString *)path;
- (NSString *)imagePath;
- (NSString *)imageName;
- (NSString *)imageType;
- (NSString *)imageSize;
- (NSString *)imageFileModificationDate;
- (NSString *)imageFilePermissions;
- (NSString *)imageFileOwner;
- (NSString *)imageResolution;
- (NSString *)bitsPerSample;
- (NSString *)colorSpaceName;
- (NSString *)hasAlpha;
- (NSString *)imageReps;

@end

#endif // _IMAGESHOWING_H_
