/* 
 * PrefController+InterfaceCreation.h created by probert on 2003-06-29 17:40:08 +0000
 *
 * Project ImageViewer
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: PrefController+InterfaceCreation.h,v 1.1 2003/06/29 17:48:09 probert Exp $
 */

#ifndef _PREFCONTROLLER_INTERFACECREATION_H_
#define _PREFCONTROLLER_INTERFACECREATION_H_

#include "PrefController.h"

@interface PrefController (InterfaceCreation)

- (void)_createUI;

@end

#endif

