/* 
 * Defines.h created by probert on 2003-06-29 16:58:59 +0000
 *
 * Project ImageViewer
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: Defines.h,v 1.1 2003/06/29 17:06:37 probert Exp $
 */

#ifndef _DEFINES_H_
#define _DEFINES_H_

#include <Foundation/Foundation.h>

#ifndef GNUSTEP_BASE_VERSION
#define NSLocalizedString(key, comment) \
    [[NSBundle mainBundle] localizedStringForKey:(key) value:@"" table:nil]

#define _(X) NSLocalizedString (X, @"")
#endif

#endif // _DEFINES_H_

