/* 
 * PrefController.h created by probert on 2001-11-15 20:24:09 +0000
 *
 * Project ImageViewer
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: PrefController.h,v 1.5 2003/06/29 17:28:34 probert Exp $
 */

#ifndef _PREFCONTROLLER_H_
#define _PREFCONTROLLER_H_

#include <AppKit/AppKit.h>

@interface PrefController : NSObject
{
    NSWindow *preferences;
    NSMutableDictionary *prefDict;

    id cacheSizeField;
    id openRecursive;
}

-(id)init;

- (void)show;
- (void)setCacheSize:(id)sender;
- (void)setOpenRecursive:(id)sender;

- (void)buttonsPressed:(id)sender;

- (void)resetPreferences;
- (void)setPreferences;

@end

#endif // _PREFCONTROLLER_H_

