/* 
 * ImageHolder.h created by probert on 2001-11-18 13:49:17 +0000
 *
 * Project ImageViewer
 *
 * Created with ProjectCenter - http://www.gnustep.org
 *
 * $Id: ImageHolder.h,v 1.4 2003/06/29 17:28:34 probert Exp $
 */

#ifndef _IMAGEHOLDER_H_
#define _IMAGEHOLDER_H_

#include <Foundation/Foundation.h>

@class NSImage;

@interface ImageHolder : NSObject
{
    NSImage *image;
    NSArray *imageReps;
    NSDictionary *attributes;
}

- (id)initWithImage:(NSImage*)img reps:(NSArray *)r attributes:(NSDictionary*)d;

- (NSImage *)image;
- (NSArray *)imageReps;
- (NSDictionary *)attributes;

@end

#endif // _IMAGEHOLDER_H_

